package survey_test

import (
	"encoding/json"
	"fmt"
	"testing"

	"gogs.uu.mdfitnesscao.com/hys/sdk"
	"gogs.uu.mdfitnesscao.com/hys/sdk/survey"
)

func TestTranslateDate(t *testing.T) {
	// 年龄
	age := survey.TranslateDate("1996-01-02 14:00:00", survey.DATE_TYPE_AGE, "")
	fmt.Println("当前年龄", age)
	age = survey.TranslateDate("2023-05-05 14:00:00", survey.DATE_TYPE_DATE, "")
	fmt.Println("当前时间", age)
	age = survey.TranslateDate("2023-05-05 14:00:00", survey.DATE_TYPE_DATETIME, "")
	fmt.Println("当前时间分钟", age)
	age = survey.TranslateDate("2023-05-05 14:00:00", survey.DATE_TYPE_DAY, "2000-01-01 00:00:00")
	fmt.Println("距离天数", age)
	age = survey.TranslateDate("2023-05-05 14:00:00", survey.DATE_TYPE_HOUR, "2000-01-01 00:00:00")
	fmt.Println("距离小时", age)
}

func TestMockData(t *testing.T) {
	var questions = map[string]sdk.SurveyAnswer{
		"QUName": {
			Type:            survey.TYPE_INPUT,
			QuestionNo:      "QUName",
			MultipleAnswers: true,
			InputAnswers: sdk.QuestionInputAnswerModel{
				Value: []string{"张三", "李四"},
				Key:   "name",
			},
		},
		"QUAddress": {
			Type:            survey.TYPE_INPUT,
			QuestionNo:      "QUAddress",
			MultipleAnswers: false,
			InputAnswers: sdk.QuestionInputAnswerModel{
				Value: []string{"北京市朝阳区"},
				Key:   "address",
			},
		},
		"QUGender": {
			Type:            survey.TYPE_RADIO,
			QuestionNo:      "QUGender",
			MultipleAnswers: false,
			Answer: sdk.QuestionAnswerModel{
				Value: "男",
				Key:   "gender",
			},
		},
		"QUBirthday": {
			Type:            survey.TYPE_DATE,
			QuestionNo:      "QUBirthday",
			MultipleAnswers: false,
			Answer: sdk.QuestionAnswerModel{
				Value: "1990-01-01",
				Key:   "birthday",
			},
		},
		"QUDisease": {
			Type:            survey.TYPE_CHECKBOX,
			QuestionNo:      "QUDisease",
			MultipleAnswers: false,
			CheckboxAnswers: []sdk.QuestionAnswerModel{
				{
					Value: "高血压",
					Key:   "hypertension",
				},
				{
					Value: "糖尿病",
					Key:   "diabetes",
				},
			},
		},
		"QUDiseaseFamily": {
			Type:            survey.TYPE_MATRIX_CHECKBOX,
			QuestionNo:      "QUDiseaseFamily",
			MultipleAnswers: false,
			MatrixAnswers: []sdk.QuestionMatrixAnswerModel{
				{
					XKey:  "dad",
					XText: "父亲",
					YKey:  "hypertension",
					YText: "高血压",
				},
				{
					XKey:  "dad",
					XText: "父亲",
					YKey:  "diabetes",
					YText: "糖尿病",
				},
				{
					XKey:  "mom",
					XText: "母亲",
					YKey:  "hypertension",
					YText: "高血压",
				},
			},
		},
		"QUDiseaseHistory": {
			Type:            survey.TYPE_GROUP,
			QuestionNo:      "QUDiseaseHistory",
			MultipleAnswers: true,
			GroupAnswers: [][]sdk.SurveyAnswer{
				{
					{
						Type:       survey.TYPE_RADIO,
						QuestionNo: "QUDisease",
						Answer: sdk.QuestionAnswerModel{
							Value: "高血压",
							Key:   "hypertension",
						},
					},
					{
						Type:       survey.TYPE_DATE,
						QuestionNo: "QUDiseaseDate",
						Answer: sdk.QuestionAnswerModel{
							Value: "2020-01-01",
							Key:   "hypertensionDate",
						},
					},
				},
				{
					{
						Type:       survey.TYPE_RADIO,
						QuestionNo: "QUDisease",
						Answer: sdk.QuestionAnswerModel{
							Value: "糖尿病",
							Key:   "diabetes",
						},
					},
					{
						Type:       survey.TYPE_DATE,
						QuestionNo: "QUDiseaseDate",
						Answer: sdk.QuestionAnswerModel{
							Value: "2019-01-01",
							Key:   "diabetesDate",
						},
					},
				},
			},
		},
	}
	jsonText, _ := json.Marshal(questions)
	fmt.Println(jsonText)

}
